summaryrefslogtreecommitdiff
path: root/iup/src/iup_attrib.h
diff options
context:
space:
mode:
Diffstat (limited to 'iup/src/iup_attrib.h')
-rwxr-xr-xiup/src/iup_attrib.h13
1 files changed, 10 insertions, 3 deletions
diff --git a/iup/src/iup_attrib.h b/iup/src/iup_attrib.h
index 993dd3c..8593d6e 100755
--- a/iup/src/iup_attrib.h
+++ b/iup/src/iup_attrib.h
@@ -28,7 +28,7 @@ extern "C" {
/** Returns true if the attribute name if in the internal format "_IUP...".
* \ingroup attrib */
-#define iupAttribIsInternal(_name) ((_name[0] == '_' && _name[1] == 'I' && _name[2] == 'U' && _name[3] == 'P')? 1: 0)
+#define iupATTRIB_ISINTERNAL(_name) ((_name[0] == '_' && _name[1] == 'I' && _name[2] == 'U' && _name[3] == 'P')? 1: 0)
/** Returns true if the attribute name is a known pointer.
* \ingroup attrib */
@@ -102,16 +102,23 @@ float iupAttribGetFloat(Ihandle* ih, const char* name);
* \ingroup attrib */
void iupAttribSetHandleName(Ihandle *ih);
+/** Returns the internal name if set.
+ * \ingroup attrib */
+char* iupAttribGetHandleName(Ihandle *ih);
+
/* For all attributes in the evironment, call the class SetAttribute only.
* Called only after the element is mapped. */
void iupAttribUpdate(Ihandle* ih);
/* For all registered inherited attributes, checks the parent tree and
* call the class SetAttribute if the attribute is defined.
* Called only after the element is mapped. */
void iupAttribUpdateFromParent(Ihandle* ih);
+/* For all attributes in the evironment, call the class SetAttribute only for the children.
+ * Called only after the element is mapped, and after the children are mapped. */
+void iupAttribUpdateChildren(Ihandle* ih);
/* Other functions declared in <iup.h> and implemented here.
@@ -102,16 +102,23 @@ float iupAttribGetFloat(Ihandle* ih, const char* name);
/* For all attributes in the evironment, call the class SetAttribute only.
- * Called only after the element is mapped. */
+ * Called only after the element is mapped, but before the children are mapped. */
void iupAttribUpdate(Ihandle* ih);
/* For all registered inherited attributes, checks the parent tree and
@@ -102,16 +102,23 @@ float iupAttribGetFloat(Ihandle* ih, const char* name);
/* For all registered inherited attributes, checks the parent tree and
* call the class SetAttribute if the attribute is defined.
- * Called only after the element is mapped. */
+ * Called only after the element is mapped, but before the children are mapped. */
void iupAttribUpdateFromParent(Ihandle* ih);